netapp_ontap.models.storage_switch_ports_sfp API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_switch_ports_sfp`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageSwitchPortsSfpSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageSwitchPortsSfp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `serial_number: str GET POST PATCH`

    Storage switch port SFP serial number

  `transmitter_type: str GET POST PATCH`

    Storage switch port SFP transmitter type

    Valid choices:

    - unknown
    - long_wave_laser
    - short_wave_laser
    - long_wave_laser_cost_reduced
    - electrical
    - ten_gig_base_sr
    - ten_gig_base_lr
    - ten_gig_base_er
    - ten_gig_base_lx4
    - ten_gig_base_sw
    - ten_gig_base_lw
    - ten_gig_base_ew
  `type: str GET POST PATCH`

    Storage switch port SFP type

    Valid choices:

    - unknown
    - other
    - gbic
    - embedded
    - glm
    - gbic_with_serial_id
    - gbic_without_serial_id
    - sfp_with_serial_id
    - sfp_without_serial_id
    - xfp
    - x2_short
    - x2_medium
    - x2_tall
    - xpak_short
    - xpak_medium
    - xpak_tall
    - xenpak
    - sfp_dw_dm
    - qsfp
    - x2_dw_dm
    - gbic_not_installed
    - small_form_factor